==> jc-1.4.0.tar.gz: soot/coffi/BasicBlock.h <==
// class soot.coffi.BasicBlock

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3297e7353be9b38b soot_coffi_BasicBlock

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_BasicBlock_H_
#define _JC_soot_coffi_BasicBlock_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_java_util_Vector$object;
struct _jc_soot_coffi_BasicBlock$object;
struct _jc_soot_coffi_Instruction$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_coffi_BasicBlock$sub_refs	_jc_soot_coffi_BasicBlock$sub_refs;
typedef struct _jc_soot_coffi_BasicBlock$sub_nonrefs	_jc_soot_coffi_BasicBlock$sub_nonrefs;
typedef struct _jc_soot_coffi_BasicBlock$refs	_jc_soot_coffi_BasicBlock$refs;
typedef struct _jc_soot_coffi_BasicBlock$nonrefs	_jc_soot_coffi_BasicBlock$nonrefs;
typedef struct _jc_soot_coffi_BasicBlock$object	_jc_soot_coffi_BasicBlock$object;

typedef const struct _jc_soot_coffi_BasicBlock$vmethods	_jc_soot_coffi_BasicBlock$vmethods;
typedef const struct _jc_soot_coffi_BasicBlock$vtable	_jc_soot_coffi_BasicBlock$vtable;
typedef const struct _jc_soot_coffi_BasicBlock$vtype	_jc_soot_coffi_BasicBlock$vtype;

// Constructors
extern void _jc_soot_coffi_BasicBlock$method$_init$22abf5ca6ded0abc(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_Instruction$object *);
extern void _jc_soot_coffi_BasicBlock$method$_init$1bcccc61858c25ec(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_Instruction$object *, struct _jc_soot_coffi_Instruction$object *);

// Virtual methods
extern jboolean _jc_soot_coffi_BasicBlock$method$equals$3f4e8e49a3a387b5(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_BasicBlock$object *);
extern struct _jc_object *_jc_soot_coffi_BasicBlock$method$getHeadJStmt$489b4242080b0e0a(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
extern struct _jc_object *_jc_soot_coffi_BasicBlock$method$getTailJStmt$31eb3d5757c30233(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
extern jint _jc_soot_coffi_BasicBlock$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_BasicBlock$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
extern jint _jc_soot_coffi_BasicBlock$method$wideIndex$17139cca24d36699(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, jshort);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$equals$3f4e8e49a3a387b5;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$getHeadJStmt$489b4242080b0e0a;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$getTailJStmt$31eb3d5757c30233;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$wideIndex$17139cca24d36699;

// Virtual methods structure
struct _jc_soot_coffi_BasicBlock$vmethods {
	jboolean	(*equals$3f4e8e49a3a387b5)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_BasicBlock$object *);
	struct _jc_object	*(*getHeadJStmt$489b4242080b0e0a)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
	struct _jc_object	*(*getTailJStmt$31eb3d5757c30233)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *);
	jint	(*wideIndex$17139cca24d36699)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, jshort);
};

// Vtable
struct _jc_soot_coffi_BasicBlock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_BasicBlock$vmethods	soot_coffi_BasicBlock;
};

// Vtype
struct _jc_soot_coffi_BasicBlock$vtype {
	_jc_type			type;
	_jc_soot_coffi_BasicBlock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_BasicBlock$sub_refs {
	struct _jc_soot_coffi_Instruction$object	*head;
	struct _jc_soot_coffi_Instruction$object	*tail;
	struct _jc_java_util_Vector$object	*succ;
	struct _jc_java_util_Vector$object	*pred;
	struct _jc_soot_coffi_BasicBlock$object	*next;
	struct _jc_object	*stmt;
	struct _jc_object	*statements;
	struct _jc_object	*addressesToFixup;
};

// Reference instance fields (object)
struct _jc_soot_coffi_BasicBlock$refs {
    _jc_soot_coffi_BasicBlock$sub_refs	soot_coffi_BasicBlock;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_BasicBlock$sub_nonrefs {
	jint	size;
	jboolean	inq;
	jboolean	beginException;
	jboolean	beginCode;
	jboolean	done;
	jlong	id;
	jshort	wide;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_BasicBlock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_BasicBlock$sub_nonrefs	soot_coffi_BasicBlock;
};

// Object instance structure
struct _jc_soot_coffi_BasicBlock$object {
	_jc_soot_coffi_BasicBlock$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_BasicBlock$vtype	*vtype;
	_jc_soot_coffi_BasicBlock$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_BasicBlock$vtype _jc_soot_coffi_BasicBlock$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_BasicBlock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_BasicBlock$class_object;

#endif	/* _JC_soot_coffi_BasicBlock_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/BasicBlock.h <==
// class soot.coffi.BasicBlock

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3297e7353be9b38b soot_coffi_BasicBlock

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_BasicBlock_H_
#define _JC_soot_coffi_BasicBlock_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_java_util_Vector$object;
struct _jc_soot_coffi_BasicBlock$object;
struct _jc_soot_coffi_Instruction$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_coffi_BasicBlock$sub_refs	_jc_soot_coffi_BasicBlock$sub_refs;
typedef struct _jc_soot_coffi_BasicBlock$sub_nonrefs	_jc_soot_coffi_BasicBlock$sub_nonrefs;
typedef struct _jc_soot_coffi_BasicBlock$refs	_jc_soot_coffi_BasicBlock$refs;
typedef struct _jc_soot_coffi_BasicBlock$nonrefs	_jc_soot_coffi_BasicBlock$nonrefs;
typedef struct _jc_soot_coffi_BasicBlock$object	_jc_soot_coffi_BasicBlock$object;

typedef const struct _jc_soot_coffi_BasicBlock$vmethods	_jc_soot_coffi_BasicBlock$vmethods;
typedef const struct _jc_soot_coffi_BasicBlock$vtable	_jc_soot_coffi_BasicBlock$vtable;
typedef const struct _jc_soot_coffi_BasicBlock$vtype	_jc_soot_coffi_BasicBlock$vtype;

// Constructors
extern void _jc_soot_coffi_BasicBlock$method$_init$22abf5ca6ded0abc(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_BasicBlock$method$_init$1bcccc61858c25ec(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_Instruction$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_coffi_BasicBlock$method$equals$3f4e8e49a3a387b5(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_coffi_BasicBlock$method$getHeadJStmt$489b4242080b0e0a(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_coffi_BasicBlock$method$getTailJStmt$31eb3d5757c30233(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_BasicBlock$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_BasicBlock$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_BasicBlock$method$wideIndex$17139cca24d36699(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, jshort) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$equals$3f4e8e49a3a387b5;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$getHeadJStmt$489b4242080b0e0a;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$getTailJStmt$31eb3d5757c30233;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_BasicBlock$method_info$wideIndex$17139cca24d36699;

// Virtual methods structure
struct _jc_soot_coffi_BasicBlock$vmethods {
	jboolean	(*equals$3f4e8e49a3a387b5)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getHeadJStmt$489b4242080b0e0a)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getTailJStmt$31eb3d5757c30233)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	jint	(*wideIndex$17139cca24d36699)(_jc_env *, struct _jc_soot_coffi_BasicBlock$object *, jshort) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_BasicBlock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_BasicBlock$vmethods	soot_coffi_BasicBlock;
};

// Vtype
struct _jc_soot_coffi_BasicBlock$vtype {
	_jc_type			type;
	_jc_soot_coffi_BasicBlock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_BasicBlock$sub_refs {
	struct _jc_soot_coffi_Instruction$object	*head;
	struct _jc_soot_coffi_Instruction$object	*tail;
	struct _jc_java_util_Vector$object	*succ;
	struct _jc_java_util_Vector$object	*pred;
	struct _jc_soot_coffi_BasicBlock$object	*next;
	struct _jc_object	*stmt;
	struct _jc_object	*statements;
	struct _jc_object	*addressesToFixup;
};

// Reference instance fields (object)
struct _jc_soot_coffi_BasicBlock$refs {
    _jc_soot_coffi_BasicBlock$sub_refs	soot_coffi_BasicBlock;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_BasicBlock$sub_nonrefs {
	jint	size;
	jboolean	inq;
	jboolean	beginException;
	jboolean	beginCode;
	jboolean	done;
	jlong	id;
	jshort	wide;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_BasicBlock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_BasicBlock$sub_nonrefs	soot_coffi_BasicBlock;
};

// Object instance structure
struct _jc_soot_coffi_BasicBlock$object {
	_jc_soot_coffi_BasicBlock$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_BasicBlock$vtype	*vtype;
	_jc_soot_coffi_BasicBlock$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_BasicBlock$vtype _jc_soot_coffi_BasicBlock$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_BasicBlock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_BasicBlock$class_object;

#endif	/* _JC_soot_coffi_BasicBlock_H_ */
